import os
from xlsx import load_workbook, Book, Font, PatternFill, Cell, Sheet, Xml


def test_font_style():
    # Create a new workbook in memory
    book: Book = Book()
    sheet: Sheet = book.create_sheet("Styled Sheet", 0)

    # Set value to a cell
    cell: Cell = sheet["A1"]
    cell.value = "Hello, Styled World!"

    # Create a font and apply it to the cell
    font: Font = Font(name="Arial", size=14, bold=True, color="FF0000")
    cell.font = font

    # Create a fill and apply it to another cell
    fill_cell: Cell = sheet["B1"]
    fill_cell.value = "Hello, Filled World!"
    fill: PatternFill = PatternFill(pattern_type="solid", fg_color="FFFF00")
    fill_cell.fill = fill

    # Save the workbook to a file
    test_file: str = "test_style.xlsx"
    if os.path.exists(test_file):
        os.remove(test_file)
    book.copy(test_file)

    print(f"Workbook '{test_file}' created. Please inspect it manually for styles.")


if __name__ == "__main__":
    test_font_style()



from typing import Iterator, Optional

def hello_from_bin() -> str: ...
def load_workbook(path: str) -> "Book": ...

class Book:
    path: str
    sheetnames: list[str]

    def __init__(self, path: str = ...) -> None: ...
    def __iter__(self) -> Iterator[str]: ...
    def __getitem__(self, key: str) -> "Sheet": ...
    def __delitem__(self, key: str) -> None: ...
    def __contains__(self, key: str) -> bool: ...
    def index(self, sheet: "Sheet") -> int: ...
    def remove(self, sheet: "Sheet") -> None: ...
    def create_sheet(self, title: str, index: int) -> "Sheet": ...
    def copy(self, path: str) -> None: ...

class Sheet:
    @property
    def name(self) -> str: ...
    def __getitem__(self, key: str) -> "Cell": ...
    def cell(self, row: int, column: int) -> "Cell": ...

class Cell:
    @property
    def value(self) -> Optional[str]: ...
    @value.setter
    def value(self, value: str) -> None: ...
    @property
    def font(self) -> Optional["Font"]: ...
    @font.setter
    def font(self, font: "Font") -> None: ...
    @property
    def fill(self) -> Optional["PatternFill"]: ...
    @fill.setter
    def fill(self, font: "PatternFill") -> None: ...

class Font:
    name: Optional[str]
    size: Optional[float]
    bold: Optional[bool]
    italic: Optional[bool]
    color: Optional[str]
    def __init__(
        self,
        name: Optional[str] = ...,
        size: Optional[float] = ...,
        bold: Optional[bool] = ...,
        italic: Optional[bool] = ...,
        color: Optional[str] = ...,
    ) -> None: ...

class PatternFill:
    pattern_type: Optional[str]
    fg_color: Optional[str]
    bg_color: Optional[str]
    def __init__(
        self,
        pattern_type: Optional[str] = ...,
        fg_color: Optional[str] = ...,
        bg_color: Optional[str] = ...,
    ) -> None: ...

class Xml: ...
class XmlElement: ...



from ._core import (
    Book,
    Cell,
    Font,
    PatternFill,
    Sheet,
    Xml,
    XmlElement,
    hello_from_bin,
    load_workbook,
)

__all__ = [
    "hello",
    "load_workbook",
    "Book",
    "Sheet",
    "Cell",
    "Font",
    "PatternFill",
    "Xml",
    "XmlElement",
]


def hello() -> str:
    return hello_from_bin()
